/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.greenseeker;

import java.text.ParseException;
import java.util.EnumMap;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import org.openide.util.NbBundle;

/**
 * FileProcessor for Normal type Greenseeker sensor files.
 * @author Arjan Loermans
 */
public class GreenseekerFileProcessorNormal extends GreenseekerFileProcessor {

    public GreenseekerFileProcessorNormal(GreenseekerDataObject toProcess) {
        super(toProcess);
    }
    // Constants    
    private static final String LOGKEY_TYPE_DISPLAYNAME = NbBundle.getMessage(GreenseekerFileProcessorNormal.class, "sensor.greenseeker.fileprocessor.normal.log.displayname");
    public static final int nrOfFields = 14;


    private static final AppLogger LOG = AppLogFactory.getLogger(GreenseekerFileProcessorNormal.class);

    /**
     * Parses one record of a normal Greenseeker sensorfile.
     *
     * @param payload The record to be processed.
     * @param dataFile The SensorDataFile belonging to this sensor file.
     * @return A record represented as a Greenseeker sensordata object
     * @throws ParseException Exception occurs when date/time cannot be parsed.
     */
    @Override
    protected GreenseekerSensorData parseLine(Object[] payload) throws GreenseekerParseException {

        // First create a entity representation of a file
        //converting the differrent data
        EnumMap<GreenseekerFileDescriptionNormal, Object> map = new EnumMap<>(GreenseekerFileDescriptionNormal.class);
        try {
            for (GreenseekerFileDescriptionNormal greenseekerNormalField : GreenseekerFileDescriptionNormal.values()) {
                if (greenseekerNormalField.isMandatory()) {
                    map.put(greenseekerNormalField, payload[greenseekerNormalField.getPosition()]);
                }
            }
        } catch (Exception e) {
            throw new GreenseekerParseException(e);
        }

        GreenseekerSensorData sensorData = new GreenseekerSensorData();

        sensorData.setObjectId((Double) map.get(GreenseekerFileDescriptionNormal.OBJECTID));
        sensorData.setLongitude((Double) map.get(GreenseekerFileDescriptionNormal.LONGITUDE));
        sensorData.setLatitude((Double) map.get(GreenseekerFileDescriptionNormal.LATITUDE));
        sensorData.setSpeed((Double) map.get(GreenseekerFileDescriptionNormal.SPEED));
        sensorData.setHeading((Double) map.get(GreenseekerFileDescriptionNormal.HEADING));
        sensorData.setElevation((Double) map.get(GreenseekerFileDescriptionNormal.ELEVATION));
        sensorData.setNdvi((Double) map.get(GreenseekerFileDescriptionNormal.NDVI));
        sensorData.setVi2nd((Double) map.get(GreenseekerFileDescriptionNormal.VI_2ND));

        sensorData.setSensor10((Double) map.get(GreenseekerFileDescriptionNormal.SENSOR_10));
        sensorData.setSensor19((Double) map.get(GreenseekerFileDescriptionNormal.SENSOR_19));
        sensorData.setSensor23((Double) map.get(GreenseekerFileDescriptionNormal.SENSOR_23));
        sensorData.setSensor24((Double) map.get(GreenseekerFileDescriptionNormal.SENSOR_24));
        sensorData.setSensor26((Double) map.get(GreenseekerFileDescriptionNormal.SENSOR_26));
        sensorData.setSensor73((Double) map.get(GreenseekerFileDescriptionNormal.SENSOR_73));

        return sensorData;
    }

    /**
     * Concrete subclasses must override this method to return the displayname
     * of that sensorprocessor to be displayed in the log. For example: "ASC-340
     * Cropcircle"
     *
     * Primary use is for logging, for example: [Info] Start processing of
     * ASC-340 Cropcircle sensor file 010710AD.CSV
     *
     * @return
     */
    @Override
    protected String getLogDisplayName() {
        return LOGKEY_TYPE_DISPLAYNAME;
    }
}
