/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.greenseeker;

import java.io.IOException;
import java.util.List;
import javax.swing.Icon;
import nl.cloudfarming.client.imp.ImportProcessor;
import nl.cloudfarming.client.sensor.AbstractSensorImportProcessor;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;

/**
 * Import processor for the Greenseeker files
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages("sensor greenseeker format description=Greenseeker Sensor file (*.dbf)")
@ServiceProvider(service = ImportProcessor.class)
public class GreenseekerImportProcessor extends AbstractSensorImportProcessor {

    public static final String GREENSEEKER_FOLDER = "Greenseeker";
    private static final Icon ICON = ImageUtilities.loadImageIcon(GreenseekerDataObject.ICON_BASE, true);

    @Override
    public String[] getSupportedExtentions() {
        return new String[]{"dbf"};
    }

    @Override
    public boolean isSupported(FileObject importFile) {
        return GreenseekerDataObject.MIME_TYPE.equals(importFile.getMIMEType());
    }

    @Override
    public String getFormatDescription() {
        return Bundle.sensor_greenseeker_format_description();
    }

    @Override
    public Icon getIcon() {
        return ICON;
    }

    @Override
    public void process(FileObject importFile, Project project) throws IllegalArgumentException {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public <T> void process(FileObject importFile, Project project, List<T> toPopulate) throws IllegalArgumentException {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    protected FileObject getSensorImportSubFolder(Project project) throws IOException {
        return getSubFolder(getSensorImportRootFolder(project), GREENSEEKER_FOLDER);
    }    
}
